![Logo](https://github.com/boonlogic/amber-python-sdk/blob/master/docs/BoonLogic.png?raw=true)

# Boon Amber Python SDK

Version 2 of Amber Python is Deploying in the spring of 2023.  This SDK will support both v1 and v2 releases.
v1 users will not see any interface difference when updating to the latest pypi package.

- __Version 1__: [Boon Amber Version 1](https://boonlogic.github.io/amber-python-sdk/boonamber/v1)
- __Version 2__: [Boon Amber Version 2](https://boonlogic.github.io/amber-python-sdk/boonamber/v2)
